@@ -121,7 +121,8 @@ class IsomorphismMolAtomMapper(AbstractMolAtomMapper):
         isomorph = ob.vvpairUIntUInt()
         isomapper.MapAll(obmol2, isomorph)
 
-        sorted_isomorph = [sorted(x, key=lambda p: p[0]) for x in isomorph]
+        sorted_isomorph = [sorted(x, key=lambda morp: morp[0])
+                           for x in isomorph]
         label2_list = tuple([tuple([p[1] + 1 for p in x])
                              for x in sorted_isomorph])
 
@@ -131,8 +132,10 @@ class IsomorphismMolAtomMapper(AbstractMolAtomMapper):
         least_rmsd = float("Inf")
         best_label2 = None
         label1 = range(1, obmol1.NumAtoms() + 1)
+        # noinspection PyProtectedMember
         elements1 = InchiMolAtomMapper._get_elements(vmol1, label1)
         for label2 in label2_list:
+            # noinspection PyProtectedMember
             elements2 = InchiMolAtomMapper._get_elements(obmol2, label2)
             if elements1 != elements2:
                 continue
@@ -151,10 +154,10 @@ class IsomorphismMolAtomMapper(AbstractMolAtomMapper):
         """
         Return inchi as molecular hash
         """
-        obConv = ob.OBConversion()
-        obConv.SetOutFormat("inchi")
-        obConv.AddOption("X", ob.OBConversion.OUTOPTIONS, "DoNotAddH")
-        inchi_text = obConv.WriteString(mol)
+        obconv = ob.OBConversion()
+        obconv.SetOutFormat("inchi")
+        obconv.AddOption("X", ob.OBConversion.OUTOPTIONS, "DoNotAddH")
+        inchi_text = obconv.WriteString(mol)
         match = re.search("InChI=(?P<inchi>.+)\n", inchi_text)
         return match.group("inchi")
 
@@ -190,7 +193,8 @@ class InchiMolAtomMapper(AbstractMolAtomMapper):
     def from_dict(cls, d):
         return InchiMolAtomMapper(angle_tolerance=d["angle_tolerance"])
 
-    def _inchi_labels(self, mol):
+    @staticmethod
+    def _inchi_labels(mol):
         """
         Get the inchi canonical labels of the heavy atoms in the molecule
 
@@ -202,12 +206,13 @@ class InchiMolAtomMapper(AbstractMolAtomMapper):
             original label
             List of equivalent atoms.
         """
-        obConv = ob.OBConversion()
-        obConv.SetOutFormat("inchi")
-        obConv.AddOption("a", ob.OBConversion.OUTOPTIONS)
-        obConv.AddOption("X", ob.OBConversion.OUTOPTIONS, "DoNotAddH")
-        inchi_text = obConv.WriteString(mol)
-        match = re.search("InChI=(?P<inchi>.+)\nAuxInfo=.+/N:(?P<labels>[0-9,;]+)/(E:(?P<eq_atoms>[0-9,"
+        obconv = ob.OBConversion()
+        obconv.SetOutFormat("inchi")
+        obconv.AddOption("a", ob.OBConversion.OUTOPTIONS)
+        obconv.AddOption("X", ob.OBConversion.OUTOPTIONS, "DoNotAddH")
+        inchi_text = obconv.WriteString(mol)
+        match = re.search("InChI=(?P<inchi>.+)\nAuxInfo=.+"
+                          "/N:(?P<labels>[0-9,;]+)/(E:(?P<eq_atoms>[0-9,"
                           ";\(\)]*)/)?", inchi_text)
         inchi = match.group("inchi")
         label_text = match.group("labels")
@@ -222,7 +227,8 @@ class InchiMolAtomMapper(AbstractMolAtomMapper):
                               for t in eq_tokens])
         return heavy_atom_labels, eq_atoms, inchi
 
-    def _group_centroid(self, mol, ilabels, group_atoms):
+    @staticmethod
+    def _group_centroid(mol, ilabels, group_atoms):
         """
         Calculate the centroids of a group atoms indexed by the labels of inchi
 
@@ -293,7 +299,8 @@ class InchiMolAtomMapper(AbstractMolAtomMapper):
 
         return vmol
 
-    def _align_heavy_atoms(self, mol1, mol2, vmol1, vmol2, ilabel1, ilabel2,
+    @staticmethod
+    def _align_heavy_atoms(mol1, mol2, vmol1, vmol2, ilabel1, ilabel2,
                            eq_atoms):
         """
         Align the label of topologically identical atoms of second molecule
@@ -372,11 +379,12 @@ class InchiMolAtomMapper(AbstractMolAtomMapper):
                                  for canon, inchi, orig in
                                  zip(canon_label2, range(1, nheavy + 1),
                                      ilabel2)]
-        canon_inchi_orig_map2.sort(key=lambda x: x[0])
+        canon_inchi_orig_map2.sort(key=lambda m: m[0])
         heavy_atom_indices2 = tuple([x[2] for x in canon_inchi_orig_map2])
         return heavy_atom_indices2
 
-    def _align_hydrogen_atoms(self, mol1, mol2, heavy_indices1,
+    @staticmethod
+    def _align_hydrogen_atoms(mol1, mol2, heavy_indices1,
                               heavy_indices2):
         """
         Align the label of topologically identical atoms of second molecule
@@ -436,7 +444,7 @@ class InchiMolAtomMapper(AbstractMolAtomMapper):
         hydrogen_canon_orig_map2 = [(canon, orig) for canon, orig
                                     in zip(hydrogen_label2,
                                            hydrogen_orig_idx2)]
-        hydrogen_canon_orig_map2.sort(key=lambda x: x[0])
+        hydrogen_canon_orig_map2.sort(key=lambda m: m[0])
         hydrogen_canon_indices2 = [x[1] for x in hydrogen_canon_orig_map2]
 
         canon_label1 = label1
@@ -499,6 +507,9 @@ class InchiMolAtomMapper(AbstractMolAtomMapper):
         vmol1 = self._virtual_molecule(obmol1, ilabel1, iequal_atom1)
         vmol2 = self._virtual_molecule(obmol2, ilabel2, iequal_atom2)
 
+        if vmol1.NumAtoms() != vmol2.NumAtoms():
+            return None, None
+
         if vmol1.NumAtoms() < 3 or self._is_molecule_linear(vmol1) \
                 or self._is_molecule_linear(vmol2):
             # using isomorphism for difficult (actually simple) molecules
@@ -515,7 +526,8 @@ class InchiMolAtomMapper(AbstractMolAtomMapper):
             elements2 = self._get_elements(obmol2, clabel2)
 
             if elements1 != elements2:
-                raise Exception("Design Error! Atomic elements are inconsistent")
+                raise Exception("Design Error! "
+                                "Atomic elements are inconsistent")
 
         return clabel1, clabel2
 
@@ -571,7 +583,8 @@ class MoleculeMatcher(MSONable):
             return float("Inf")
         return self._calc_rms(mol1, mol2, label1, label2)
 
-    def _calc_rms(self, mol1, mol2, clabel1, clabel2):
+    @staticmethod
+    def _calc_rms(mol1, mol2, clabel1, clabel2):
         """
         Calculate the RMSD.
 
@@ -641,7 +654,7 @@ class MoleculeMatcher(MSONable):
             alone_mols = set(rg) - not_alone_mols
             group_indices.extend([[m] for m in alone_mols])
             while len(not_alone_mols) > 0:
-                current_group = set([not_alone_mols.pop()])
+                current_group = {not_alone_mols.pop()}
                 while len(not_alone_mols) > 0:
                     candidate_pairs = set(
                         [tuple(sorted(p)) for p
