@@ -34,8 +34,7 @@ from pymatgen.serializers.json_coders import MSONable
 from pymatgen.core.sites import Site, PeriodicSite
 from pymatgen.core.bonds import CovalentBond, get_bond_length
 from pymatgen.core.composition import Composition
-from pymatgen.util.coord_utils import get_points_in_sphere_pbc, get_angle, \
-    pbc_all_distances, all_distances
+from pymatgen.util.coord_utils import get_angle, all_distances
 from monty.design_patterns import singleton
 from pymatgen.core.units import Mass, Length
 from monty.dev import deprecated
@@ -391,8 +390,8 @@ class IStructure(SiteCollection, MSONable):
         Returns the distance matrix between all sites in the structure. For
         periodic structures, this should return the nearest image distance.
         """
-        return pbc_all_distances(self.lattice, self.frac_coords,
-                                 self.frac_coords)
+        return self.lattice.get_all_distances(self.frac_coords,
+                                              self.frac_coords)
 
     @property
     def sites(self):
@@ -519,8 +518,8 @@ class IStructure(SiteCollection, MSONable):
         """
         site_fcoords = np.mod(self.frac_coords, 1)
         neighbors = []
-        for fcoord, dist, i in get_points_in_sphere_pbc(self._lattice,
-                                                        site_fcoords, pt, r):
+        for fcoord, dist, i in self._lattice.get_points_in_sphere(
+                site_fcoords, pt, r):
             nnsite = PeriodicSite(self[i].species_and_occu,
                                   fcoord, self._lattice,
                                   properties=self[i].properties)
@@ -675,15 +674,16 @@ class IStructure(SiteCollection, MSONable):
 
         Args:
             site_properties (dict): Properties to add or override. The
-                properties are specified in the same way as the constructor, i.e.,
-                as a dict of the form {property: [values]}. The properties
-                should be in the order of the *original* structure if you
-                are performing sanitization.
+                properties are specified in the same way as the constructor,
+                i.e., as a dict of the form {property: [values]}. The
+                properties should be in the order of the *original* structure
+                if you are performing sanitization.
             sanitize (bool): If True, this method will return a sanitized
-                structure. Sanitization performs a few things: (i) The sites are sorted
-                by electronegativity, (ii) a LLL lattice reduction is carried
-                out to obtain a relatively orthogonalized cell, (iii) all
-                fractional coords for sites are mapped into the unit cell.
+                structure. Sanitization performs a few things: (i) The sites are
+                sorted by electronegativity, (ii) a LLL lattice reduction is
+                carried out to obtain a relatively orthogonalized cell,
+                (iii) all fractional coords for sites are mapped into the
+                unit cell.
 
         Returns:
             A copy of the Structure, with optionally new site_properties and
@@ -1395,8 +1395,8 @@ class IMolecule(SiteCollection, MSONable):
                     new_coords = np.dot(m, centered_coords.T).T + box_center
                     if len(coords) == 0:
                         break
-                    distances = pbc_all_distances(
-                        lattice, lattice.get_fractional_coords(new_coords),
+                    distances = lattice.get_all_distances(
+                        lattice.get_fractional_coords(new_coords),
                         lattice.get_fractional_coords(coords))
                     if np.amin(distances) > min_dist:
                         break
@@ -2351,7 +2351,9 @@ class FunctionalGroups(dict):
         """
         Loads functional group data from json file. Return list that can be
         easily converted into a Molecule object. The .json file, of course,
-        has to be under the same directory of this function"""
+        has to be under the same directory of this function
+        """
+        dict.__init__(self)
         with open(os.path.join(os.path.dirname(__file__),
                                "func_groups.json")) as f:
             for k, v in json.load(f).items():
