@@ -386,7 +386,7 @@ class Poscar(MSONable):
             for v in self.predictor_corrector[2:]:
                 lines.append(" ".join([format_str.format(i) for i in v]))
 
-        return "\n".join(lines)
+        return "\n".join(lines) + "\n"
 
     def __str__(self):
         """
@@ -400,7 +400,7 @@ class Poscar(MSONable):
         the Poscar.get_string method and are passed through directly.
         """
         with open(filename, "w") as f:
-            f.write(self.get_string(**kwargs) + "\n")
+            f.write(self.get_string(**kwargs))
 
     @property
     def to_dict(self):
@@ -535,9 +535,9 @@ class Incar(dict):
                 lines.append([k, self[k]])
 
         if pretty:
-            return str_aligned(lines)
+            return str_aligned(lines) + "\n"
         else:
-            return str_delimited(lines, None, " = ")
+            return str_delimited(lines, None, " = ") + "\n"
 
     def __str__(self):
         return self.get_string(sort_keys=True, pretty=False)
@@ -550,7 +550,7 @@ class Incar(dict):
             filename (str): filename to write to.
         """
         with open(filename, "w") as f:
-            f.write(self.__str__() + "\n")
+            f.write(self.__str__())
 
     @staticmethod
     def from_file(filename):
@@ -881,6 +881,43 @@ class Kpoints(MSONable):
         num_kpts = 0
         return Kpoints(comment, num_kpts, style, [num_div], [0, 0, 0])
 
+    @staticmethod
+    def automatic_linemode(divisions, ibz):
+        """
+        Convenient static constructor for a KPOINTS in mode line_mode.
+        gamma centered Monkhorst-Pack grids and the number of subdivisions
+        along each reciprocal lattice vector determined by the scheme in the
+        VASP manual.
+
+        Args:
+            divisions: Parameter determining the number of k-points along each
+                hight symetry lines.
+            ibz: HighSymmKpath object (pymatgen.symmetry.bandstructure)
+
+        Returns:
+            Kpoints object
+        """
+        kpoints = list()
+        labels = list()
+        for path in ibz.kpath["path"]:
+            kpoints.append(ibz.kpath["kpoints"][path[0]])
+            labels.append(path[0])
+            for i in range(1, len(path) - 1):
+                kpoints.append(ibz.kpath["kpoints"][path[i]])
+                labels.append(path[i])
+                kpoints.append(ibz.kpath["kpoints"][path[i]])
+                labels.append(path[i])
+
+            kpoints.append(ibz.kpath["kpoints"][path[-1]])
+            labels.append(path[-1])
+
+        return Kpoints("Line_mode KPOINTS file",
+                       style=Kpoints.supported_modes.Line_mode,
+                       coord_type="Reciprocal",
+                       kpts=kpoints,
+                       labels=labels,
+                       num_kpts=int(divisions))
+
     @staticmethod
     def from_file(filename):
         """
@@ -991,17 +1028,19 @@ class Kpoints(MSONable):
             filename (str): Filename to write to.
         """
         with open(filename, "w") as f:
-            f.write(self.__str__() + "\n")
+            f.write(self.__str__())
 
     def __str__(self):
         lines = [self.comment, str(self.num_kpts), self.style]
         style = self.style.lower()[0]
-        if style == "Line-mode":
+        if style == "l":
             lines.append(self.coord_type)
         for i in xrange(len(self.kpts)):
             lines.append(" ".join([str(x) for x in self.kpts[i]]))
             if style == "l":
                 lines[-1] += " ! " + self.labels[i]
+                if i % 2 == 1:
+                    lines[-1] += "\n"
             elif self.num_kpts > 0:
                 if self.labels is not None:
                     lines[-1] += " %i %s" % (self.kpts_weights[i],
@@ -1022,7 +1061,7 @@ class Kpoints(MSONable):
         #Print shifts for automatic kpoints types if not zero.
         if self.num_kpts <= 0 and tuple(self.kpts_shift) != (0, 0, 0):
             lines.append(" ".join([str(x) for x in self.kpts_shift]))
-        return "\n".join(lines)
+        return "\n".join(lines) + "\n"
 
     @property
     def to_dict(self):
@@ -1109,12 +1148,11 @@ class PotcarSingle(object):
         self.keywords = dict(keypairs)
 
     def __str__(self):
-        return self.data
+        return self.data + "\n"
 
     def write_file(self, filename):
-        writer = open(filename, "w")
-        writer.write(self.__str__() + "\n")
-        writer.close()
+        with zopen(filename, "w") as f:
+            f.write(self.__str__())
 
     @staticmethod
     def from_file(filename):
@@ -1239,7 +1277,7 @@ class Potcar(list):
         return potcar
 
     def __str__(self):
-        return "\n".join([str(potcar).strip("\n") for potcar in self])
+        return "\n".join([str(potcar).strip("\n") for potcar in self]) + "\n"
 
     def write_file(self, filename):
         """
@@ -1249,7 +1287,7 @@ class Potcar(list):
             filename (str): filename to write to.
         """
         with open(filename, "w") as f:
-            f.write(self.__str__() + "\n")
+            f.write(self.__str__())
 
     @property
     def symbols(self):
