@@ -28,6 +28,7 @@ except ImportError:
     from pyhull.convex_hull import ConvexHull
     HULL_METHOD = "pyhull"
 
+from pymatgen.core.periodic_table import get_el_sp
 from pymatgen.core.composition import Composition
 from pymatgen.phasediagram.entries import GrandPotPDEntry, TransformedPDEntry
 from pymatgen.entries.computed_entries import ComputedEntry
@@ -136,8 +137,8 @@ class PhaseDiagram (MSONable):
         #This is significantly faster than grouping by composition and then
         #taking the lowest energy of each group
         ind = []
-        prev_c = [] #compositions within 1e-4 of current entry
-        prev_e = [] #energies of those compositions
+        prev_c = []  # compositions within 1e-4 of current entry
+        prev_e = []  # energies of those compositions
         for i in np.argsort([e.energy_per_atom for e in entries]):
             if form_e[i] > -self.formation_energy_tol:
                 continue
@@ -146,10 +147,11 @@ class PhaseDiagram (MSONable):
             while prev_e and epa > 1e-4 + prev_e[0]:
                 prev_c.pop(0)
                 prev_e.pop(0)
-            if entries[i].composition.get_fractional_composition() not in prev_c:
+            frac_comp = entries[i].composition.get_fractional_composition()
+            if frac_comp not in prev_c:
                 ind.append(i)
             prev_e.append(epa)
-            prev_c.append(entries[i].composition.get_fractional_composition())
+            prev_c.append(frac_comp)
 
         #add the elemental references
         ind.extend(map(entries.index, el_refs.values()))
@@ -157,6 +159,12 @@ class PhaseDiagram (MSONable):
         qhull_entries = [entries[i] for i in ind]
         qhull_data = data[ind][:, 1:]
 
+        #add an extra point to enforce full dimensionality
+        #this point will be present in all upper hull facets
+        extra_point = np.zeros(dim) + 1 / dim
+        extra_point[-1] = np.max(qhull_data) + 1
+        qhull_data = np.concatenate([qhull_data, [extra_point]], axis=0)
+
         if len(qhull_data) == dim:
             self.facets = [range(dim)]
         else:
@@ -166,13 +174,13 @@ class PhaseDiagram (MSONable):
                 facets = ConvexHull(qhull_data, joggle=False).vertices
             finalfacets = []
             for facet in facets:
-                is_non_element_facet = any(
-                    (len(qhull_entries[i].composition) > 1 for i in facet))
-                if is_non_element_facet:
-                    m = qhull_data[facet]
-                    m[:, -1] = 1
-                    if abs(np.linalg.det(m)) > 1e-8:
-                        finalfacets.append(facet)
+                #skip facets that include the extra point
+                if max(facet) == len(qhull_data)-1:
+                    continue
+                m = qhull_data[facet]
+                m[:, -1] = 1
+                if abs(np.linalg.det(m)) > 1e-8:
+                    finalfacets.append(facet)
             self.facets = finalfacets
 
         self.all_entries = entries
@@ -296,13 +304,12 @@ class GrandPotentialPhaseDiagram(PhaseDiagram):
             elements = set()
             map(elements.update, [entry.composition.elements
                                   for entry in entries])
-
-        elements = set(elements).difference(chempots.keys())
-        all_entries = [GrandPotPDEntry(e, chempots)
+        self.chempots = {get_el_sp(el): u for el, u in chempots.items()}
+        elements = set(elements).difference(self.chempots.keys())
+        all_entries = [GrandPotPDEntry(e, self.chempots)
                        for e in entries
                        if (not e.is_element) or
                        e.composition.elements[0] in elements]
-        self.chempots = chempots
 
         super(GrandPotentialPhaseDiagram, self).__init__(all_entries, elements)
 
@@ -418,17 +425,22 @@ class CompoundPhaseDiagram(PhaseDiagram):
 
     @property
     def to_dict(self):
-        return {"@module": self.__class__.__module__,
-                "@class": self.__class__.__name__,
-                "original_entries": [e.to_dict for e in self.original_entries],
-                "terminal_compositions": [c.to_dict for c in self.terminal_compositions],
-                "normalize_terminal_compositions": self.normalize_terminal_compositions}
+        return {
+            "@module": self.__class__.__module__,
+            "@class": self.__class__.__name__,
+            "original_entries": [e.to_dict for e in self.original_entries],
+            "terminal_compositions": [c.to_dict
+                                      for c in self.terminal_compositions],
+            "normalize_terminal_compositions":
+                self.normalize_terminal_compositions}
 
     @classmethod
     def from_dict(cls, d):
-        entries = PMGJSONDecoder().process_decoded(d["original_entries"])
-        terminal_compositions = PMGJSONDecoder().process_decoded(d["terminal_compositions"])
-        return cls(entries, terminal_compositions, d["normalize_terminal_compositions"])
+        dec = PMGJSONDecoder()
+        entries = dec.process_decoded(d["original_entries"])
+        terminal_compositions = dec.process_decoded(d["terminal_compositions"])
+        return cls(entries, terminal_compositions,
+                   d["normalize_terminal_compositions"])
 
 
 class PhaseDiagramError(Exception):
